<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://sare.pl/
 * @since      1.0.0
 *
 * @package    Sare_Wp
 * @subpackage Sare_Wp/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Sare_Wp
 * @subpackage Sare_Wp/admin
 * @author     Sare <hello@sare.pl>
 */
class Sare_Wp_Admin
{

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     */
    public function __construct()
    {
    }

    public function checkThatWoocommerceIsActive()
    {
        if (is_admin() && current_user_can('activate_plugins') && !is_plugin_active('woocommerce/woocommerce.php')) {
            add_action('admin_notices', 'sareWoocommercePluginNotice');

            deactivate_plugins(plugin_basename('sare-wp/sare-wp.php'));

            if (isset($_GET['action']) && $_GET['action'] == 'activate') {
                unset($_GET['action']);
            }
        }

        function sareWoocommercePluginNotice()
        {
            ?>
            <style>
                div#message.updated {
                    display: none;
                }
            </style>
            <div class="error">
                <p><?= __(
                        'To activate this plugin you need to install and activate the WooCommerce plugin.',
                        'sare-wp'
                    ) ?></p>
            </div>
            <?php
        }
    }

    public function sareAdminMenu()
    {
        add_menu_page(
            __('SARE Woocommerce', 'sare-wp'),
            __('SARE Woocommerce', 'sare-wp'),
            'manage_options',
            'sare',
            'adminSarePageConnector',
            'dashicons-email',
            64
        );

        add_submenu_page(
            'sare',
            __('Mapowanie', 'sare-wp'),
            __('Mapowanie', 'sare-wp'),
            'manage_options',
            'sare_mapper',
            'adminSarePageMapping',
            64
        );

        function adminSarePageConnector()
        {
            require_once plugin_dir_path(__FILE__) . '../includes/class-sare-wp-request-helper.php';
            require_once plugin_dir_path(__FILE__) . '../includes/class-sare-wp-config-object.php';
            sareConnector();
            $requestHelper = getRequestHelper();
            $configObject = $requestHelper ? $requestHelper->getConfigObject() : new Sare_Wp_Config_Object([]);
            ?>
            <div class="wrap">
                <h2>SARE Woocommerce</h2>
                <p><?php
                    echo __(
                        'Set up your store with the Sare system. Grant Sare WP permissions, configure connection with your account and enjoy automatic synchronization of your clients with the Sare system', 'sare-wp'
                    ) ?>
                </p>
                <a href="https://sare.pl/rejestracja/?partner=woocommerce" target="_blank"
                   class="button button-primary">
                    <?php
                    echo __(
                        'I\'m a new customer - register', 'sare-wp'
                    ) ?>
                </a>
                </p>
                <form method="post" action="<?= esc_url(admin_url('admin-post.php')) ?>">
                    <input type="hidden" name="action" value="sare_config">
                    <table class="form-table" role="presentation">
                        <tbody>
                        <tr>
                            <th scope="row">
                                <label for="uid"><?php
                                    echo __('Sare uid', 'sare-wp') ?></label>
                            </th>
                            <td>
                                <input name="uid" type="text" required id="uid" value="<?php
                                echo $configObject->getUuid() ?>"
                                       class="regular-text">
                                <p class="description" id="tagline-description">
                                    <?php
                                    echo __('Paste your sare account id', 'sare-wp') ?>
                                </p>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="apiKey"><?php
                                    echo __('API Key', 'sare-wp') ?></label></th>
                            <td><input name="apiKey" required type="text" id="apiKey"
                                       value="<?php
                                       echo $configObject->getApiKey() ?>" class="regular-text">
                                <p class="description" id="tagline-description"><?php
                                    echo __('Copy API Key from your Sare account', 'sare-wp') ?></p></td>
                        </tr>
                        <tr>
                            <th scope="row"><label for="interface"><?php
                                    echo __('Sare interface', 'sare-wp') ?></label></th>
                            <td>
                                <select name="interface" required id="interface">
                                    <option value=""><?php
                                        echo __('Select interface', 'sare-wp') ?></option>
                                    <option value="0" <?php
                                    echo $configObject->getInterface() === 0 ? 'selected' : '' ?>>0
                                    </option>
                                    <option value="1" <?php
                                    echo $configObject->getInterface() === 1 ? 'selected' : '' ?>>1
                                    </option>
                                    <option value="2" <?php
                                    echo $configObject->getInterface() === 2 ? 'selected' : '' ?>>2
                                    </option>
                                    <option value="3" <?php
                                    echo $configObject->getInterface() === 3 ? 'selected' : '' ?>>3
                                    </option>
                                    <option value="4" <?php
                                    echo $configObject->getInterface() === 4 ? 'selected' : '' ?>>4
                                    </option>
                                    <option value="5" <?php
                                    echo $configObject->getInterface() === 5 ? 'selected' : '' ?>>5
                                    </option>
                                    <option value="6" <?php
                                    echo $configObject->getInterface() === 6 ? 'selected' : '' ?>>6
                                    </option>
                                    <option value="7" <?php
                                    echo $configObject->getInterface() === 7 ? 'selected' : '' ?>>7
                                    </option>
                                    <option value="8" <?php
                                    echo $configObject->getInterface() === 8 ? 'selected' : '' ?>>8
                                    </option>
                                    <option value="9" <?php
                                    echo $configObject->getInterface() === 9 ? 'selected' : '' ?>>9
                                    </option>
                                </select>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row"><?php
                                echo __('DoubleOptIn', 'sare-wp') ?></th>
                            <td>
                                <fieldset>
                                    <legend class="screen-reader-text"><span><?php
                                            echo __('DoubleOptIn', 'sare-wp') ?></span></legend>
                                    <label for="doubleOptIn">
                                        <input name="doubleOptIn" type="checkbox" id="doubleOptIn" value="1"
                                            <?php
                                            echo $configObject->isDoubleOptIn() === true ? 'checked' : '' ?>>
                                        <?php
                                        echo __('DoubleOptIn', 'sare-wp') ?>
                                    </label>
                                </fieldset>
                            </td>
                        </tr>
                        </tbody>
                    </table>

                    <p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary"
                                             value="<?php
                                             echo __('Save changes', 'sare-wp') ?>"></p>
                </form>
            </div>
            <?php
        }

        function adminSarePageMapping()
        {
            require_once plugin_dir_path(__FILE__) . '../includes/class-sare-wp-request-helper.php';
            $requestHelper = getRequestHelper();
            ?>
            <div class="wrap">
                <h2>SARE Woocommerce</h2>
                <p><?php
                    echo __(
                        'Set up your mapping between Sare System and Customer attributes.', 'sare-wp'
                    ) ?></p>
                <form method="post" action="<?= esc_url(admin_url('admin-post.php')) ?>">
                    <input type="hidden" name="action" value="sare_sync_all">
                    <button type="submit" class="button button-primary"><?= __('Sync all', 'sare-wp') ?></button>
                </form>
                <script src="https://cdn.jsdelivr.net/npm/vue@3.2.4/dist/vue.global.prod.js"></script>
                <div id="app">
                    <p class="card-header"><b>Wybierz grupę w SARE:</b></p>
                    <select name="group" class="control"
                            @change="setUnsaved()"
                            v-if="groups.length > 0"
                            v-model="selectedGroup">
                        <option v-for="group in groups"
                                :value="group.id">
                            ${group.name}$
                            (#${group.id}$)
                        </option>
                    </select>

                    <div class="row" style="margin-top: 10px;">
                        <div class="col_xs-12">
                            <table class="table">
                                <tr>
                                    <th style="text-align: left">cecha w SARE</th>
                                    <th style="text-align: left">Atrybut Woocommerce</th>
                                    <th><a @click="addField"
                                           class="button button-primary"
                                           href="#!">+</a>
                                    </th>
                                </tr>
                                <tr v-for="(item) in map" v-bind:key="item.id">
                                    <td>
                                        <div v-if="Object.keys(emailProps).length > 0">

                                            <select name="props"
                                                    class="control"
                                                    @change="setUnsaved()"
                                                    v-model="item.prop">
                                                <option v-for="(propName, prop) in emailProps"
                                                        :value="prop">
                                                    ${this.renderPropLabel(propName,
                                                    prop)}$
                                                </option>
                                            </select>


                                        </div>
                                    </td>
                                    <td>

                                        <div v-if="Object.keys(contactFields).length > 0">


                                            <select name="contactField"
                                                    class="control"
                                                    v-model="item.field"
                                                    @change="setUnsaved()">
                                                <option v-for="(contactFieldLabel, contactField)  in contactFields"
                                                        :value="contactField">
                                                    ${contactFieldLabel}$
                                                    (${contactField}$)
                                                </option>
                                            </select>
                                        </div>
                                    </td>
                                    <td>
                                        <a @click="removeField(item)"
                                           class="button button-primary"
                                           href="#!" style="width: 30px; text-align: center">-</a>
                                    </td>
                                </tr>
                            </table>
                            <div>
                                <a @click="save()" class="button button-primary"
                                   href="#!" style="margin-top: 10px"><?= __('Save', 'sare-wp') ?></a>
                                <div id="alert-placeholder" class="mt-3">
                                    <div v-if="saveStatus != null"
                                         v-bind:class="saveStatus"
                                         class="alert"
                                         role="alert">
                                        ${saveMsg}$
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <script type="application/javascript">
                        const Mapper = {
                            delimiters: ['${', '}$'],
                            saveStatus: 'danger',
                            saveMsg: '',
                            selectedGroup: null,
                            groups: [],
                            map: [],
                            contactFields: [],
                            emailProps: [],
                            methods: {
                                log() {
                                    console.log(this.map);
                                },
                                renderPropLabel(propName, prop) {
                                    if (propName !== prop) {
                                        return propName + '(' + prop + ')';
                                    } else {
                                        return propName;
                                    }
                                },
                                setUnsaved() {
                                    this.saveStatus = null;
                                },
                                addField() {
                                    if (!Array.isArray(this.map)) {
                                        this.map = [];
                                    }
                                    this.map.push({"prop": null, "field": null});
                                    this.setUnsaved();
                                },
                                removeField(mapItem) {
                                    this.map.splice(this.map.indexOf(mapItem), 1);
                                    this.setUnsaved();
                                },
                                save() {
                                    let payload = {"mapping": [], "group": null};

                                    this.map.forEach(function (item) {
                                        payload.mapping.push({prop: item.prop, field: item.field});
                                    });
                                    payload.group = this.selectedGroup;

                                    requestOptions = {
                                        method: "POST",
                                        headers: {"Content-Type": "application/json"},
                                        body: JSON.stringify(payload)
                                    };
                                    fetch('<?php echo SARE_WP_URL ?>/save-mapping-woocommerce?hash=<?= $requestHelper->generateAuthSignature(
                                        'POST',
                                        SARE_WP_URL . '/save-mapping-woocommerce',
                                        ['shopUrl' => get_site_url()]
                                    ) ?>&shopUrl=<?= get_site_url() ?>', requestOptions)
                                        .then(response => response.json())
                                        .then(data => {
                                            this.saveMsg = data.msg;
                                            this.saveStatus = data.status;
                                        })
                                },
                            },
                            data() {
                                return {
                                    map: this.map = [],
                                    emailProps: this.emailProps,
                                    contactFields: this.contactFields,
                                    saveMsg: this.saveMsg,
                                    saveStatus: this.saveStatus,
                                    selectedGroup: this.selectedGroup,
                                    groups: this.groups = [],
                                }
                            },
                            mounted() {
                                this.groups = [];
                                this.emailProps = [];
                                this.contactFields = [];
                                fetch('<?= SARE_WP_URL ?>/groups-woocommerce?hash=<?= $requestHelper->generateAuthSignature(
                                    'GET',
                                    SARE_WP_URL . '/groups-woocommerce',
                                    ['shopUrl' => get_site_url()]
                                ) ?>&shopUrl=<?= get_site_url() ?>')
                                    .then(res => res.json())
                                    .then(data => {
                                        this.groups = data;
                                    })
                                    .catch(err => this.groups = [])
                                fetch('<?= SARE_WP_URL ?>/props-woocommerce?hash=<?= $requestHelper->generateAuthSignature(
                                    'GET',
                                    SARE_WP_URL . '/props-woocommerce',
                                    ['shopUrl' => get_site_url()]
                                ) ?>&shopUrl=<?= get_site_url() ?>')
                                    .then(res => res.json())
                                    .then(data => this.emailProps = data)
                                    .catch(err => this.emailProps = [])
                                fetch('<?php echo SARE_WP_URL ?>/contact-fields-woocommerce/users?hash=<?= $requestHelper->generateAuthSignature(
                                    'GET',
                                    SARE_WP_URL . '/contact-fields-woocommerce/users',
                                    ['shopUrl' => get_site_url()]
                                ) ?>&shopUrl=<?= get_site_url() ?>')
                                    .then(res => res.json())
                                    .then(data => this.contactFields = data)
                                    .catch(err => console.log(err.message))
                                this.map = [[]];
                                fetch('<?php echo SARE_WP_URL ?>/mapping-woocommerce?hash=<?= $requestHelper->generateAuthSignature(
                                    'GET',
                                    SARE_WP_URL . '/mapping-woocommerce',
                                    ['shopUrl' => get_site_url()]
                                ) ?>&shopUrl=<?= get_site_url() ?>')
                                    .then(res => res.json())
                                    .then(data => {
                                        this.selectedGroup = data['group']
                                        if (this.selectedGroup === undefined) {
                                            this.selectedGroup = 1;
                                        }
                                        this.map = data['mapping'];
                                    })
                                    .catch(err => console.log(err.message))
                                this.map = [[]];
                            }
                        };
                        Vue.createApp(Mapper).mount('#app')
                    </script>
                </div>
            </div>
            <?php
        }

        function sareConnector()
        {
            if (isset($_COOKIE['setup_sare_teleport']) && $_COOKIE['setup_sare_teleport'] === '1' && defined(
                    'SARE_WP_URL'
                )) {
                if (defined('SARE_WP_VERSION')) {
                    $version = SARE_WP_VERSION;
                } else {
                    $version = '1.0.0';
                }
                $sareWPUrl = SARE_WP_URL;
                $url = $sareWPUrl . '/woocommerce/gate';
                $queryParams = [
                    'action'             => 'setup',
                    'applicationCode'    => 'Sare WP',
                    'applicationVersion' => $version,
                    'shopUrl' => get_site_url()
                ];
                unset($_COOKIE['setup_sare_teleport']);
                header('Set-Cookie: setup_sare_teleport=; path=/; expires=Thu, 01 Jan 1970 00:00:00 GMT');
                header('Location: ' . $url . '?' . http_build_query($queryParams));
                exit();
            }
        }

        function getRequestHelper()
        {
            global $wpdb;
            $result = $wpdb->get_row(
                "SELECT * FROM {$wpdb->prefix}woocommerce_api_keys WHERE description LIKE 'SARE WP%'",
                ARRAY_A
            );
            if ($result !== null) {
                $requestHelper = new Sare_Wp_Request_Helper();
                $requestHelper->setConsumerSecret($result['consumer_secret']);

                return $requestHelper;
            }

            return null;
        }
    }

    public function handleSareConfig()
    {
        $filterPost = filter_input_array(INPUT_POST, [
            "uid"         => FILTER_VALIDATE_INT,
            "apiKey"      => FILTER_SANITIZE_STRING,
            "interface"   => FILTER_VALIDATE_INT,
            "doubleOptIn" => FILTER_VALIDATE_BOOLEAN,
        ]);
        $requestHelper = $this->getRequestHelper();
        $responseCode = $requestHelper->postConfigObject($filterPost);
        if ($responseCode === 200) {
            $_SESSION['sare_msg'] = __('Config saved.', 'sare-wp');
            $success = true;
        } elseif ($responseCode === 429){
            $_SESSION['sare_msg'] = __('Wrong credentials.', 'sare-wp');
            $success = false;
        } else {
            $_SESSION['sare_msg'] = __('Error while saving.', 'sare-wp');
            $success = false;
        }

        header('Location: ' . admin_url('admin.php?page=sare&success=' . (int)$success));
        exit();
    }

    public function handleSareSyncAll()
    {
        $requestHelper = $this->getRequestHelper();
        $success = $requestHelper->sendWebhook(null, 'sync.all');
        if ($success === true) {
            $_SESSION['sare_msg'] = __('Sync request was sent.', 'sare-wp');
        } else {
            $_SESSION['sare_msg'] = __('Error while send sync request.', 'sare-wp');
        }

        header('Location: ' . admin_url('admin.php?page=sare&success=' . (int)$success));
        exit();
    }

    function getRequestHelper()
    {
        require_once plugin_dir_path(__FILE__) . '../includes/class-sare-wp-request-helper.php';
        global $wpdb;
        $result = $wpdb->get_row(
            "SELECT * FROM {$wpdb->prefix}woocommerce_api_keys WHERE description LIKE 'SARE WP%'",
            ARRAY_A
        );
        if ($result !== null) {
            $requestHelper = new Sare_Wp_Request_Helper();
            $requestHelper->setConsumerSecret($result['consumer_secret']);

            return $requestHelper;
        }

        return null;
    }

    public function sareConnectorResult()
    {
        if (
            isset($_GET['page']) &&
            $_GET['page'] === 'sare' &&
            isset($_GET['oauthReturnUrl']) &&
            $_GET['oauthReturnUrl'] === '1' &&
            isset($_GET['success'])
        ) {
            if ($_GET['success'] === '1') {
                ?>
                <div class="notice notice-success is-dismissible">
                    <p><?php
                        _e(
                            'Ok! We can communicate, complete the configuration in the form below.',
                            'sample-text-domain'
                        ); ?></p>
                </div>
                <?php
            } elseif ($_GET['success'] === '0') {
                ?>
                <div class="notice notice-error is-dismissible">
                    <p><?php
                        _e(
                            'To use the plugin, we need your permission to create webhooks in the WooCommerce plugin',
                            'sample-text-domain'
                        ); ?></p>
                </div>
                <?php
            }
        }
    }

    public function sarePluginResult()
    {
        if (
            isset($_GET['page']) &&
            $_GET['page'] === 'sare' &&
            isset($_SESSION['sare_msg']) &&
            isset($_GET['success'])
        ) {
            $msg = $_SESSION['sare_msg'];
            unset($_SESSION['sare_msg'])
            ?>
            <div class="notice notice-<?= $_GET['success'] === '1' ? 'success' : 'error' ?> is-dismissible">
                <p><?php
                    _e(
                        $msg,
                        'sample-text-domain'
                    ); ?></p>
            </div>
            <?php
        }
    }

    public function sareStartSession()
    {
        if (!session_id()) {
            session_start();
        }
    }

}
