<?php

/**
 * Fired during plugin deactivation
 *
 * @link       https://sare.pl/
 * @since      1.0.0
 *
 * @package    Sare_Wp
 * @subpackage Sare_Wp/includes
 */

/**
 * Fired during plugin deactivation.
 *
 * This class defines all code necessary to run during the plugin's deactivation.
 *
 * @since      1.0.0
 * @package    Sare_Wp
 * @subpackage Sare_Wp/includes
 * @author     Sare <hello@sare.pl>
 */
class Sare_Wp_Deactivator
{


    /**
     * Short Description. (use period)
     *
     * Long Description.
     *
     * @since    1.0.0
     */
    public function deactivate(Sare_Wp_Request_Helper $requestHelper)
    {
        if (defined('SARE_WP_URL')) {
            $sareWPUrl = SARE_WP_URL;
            global $wpdb;
            $result = $wpdb->get_row(
                "SELECT * FROM {$wpdb->prefix}woocommerce_api_keys WHERE description LIKE 'SARE WP%'",
                ARRAY_A
            );
            if ($result !== null) {
                $requestHelper->setConsumerSecret($result['consumer_secret']);
                $url = $sareWPUrl . '/woocommerce/gate';
                $queryParams = [
                    'action' => 'uninstall',
                    'shopUrl' => get_site_url()
                ];
                $hash = $requestHelper->generateAuthSignature('GET', $url, $queryParams);
                $queryParams['hash'] = $hash;
                wp_remote_get($url . '?' . http_build_query($queryParams));
                $wpdb->delete(
                    "{$wpdb->prefix}woocommerce_api_keys",
                    ['key_id' => $result['key_id']]
                );
            }
        }
    }

}
