<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://sare.pl/
 * @since      1.0.0
 *
 * @package    Sare_Wp
 * @subpackage Sare_Wp/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Sare_Wp
 * @subpackage Sare_Wp/public
 * @author     Sare <hello@Sare.pl>
 */
class Sare_Wp_Public
{

    /**
     * @var Sare_Wp_Request_Helper|null
     */
    private $requestHelper;

    /**
     * Initialize the class and set its properties.
     *
     * @param Sare_Wp_Request_Helper|null $requestHelper
     * @since    1.0.0
     */
    public function __construct(Sare_Wp_Request_Helper $requestHelper = null)
    {
        $this->requestHelper = $requestHelper;
    }

    public function saveNewUser(int $customer_id): void
    {
        $this->requestHelper->sendWebhook($customer_id, 'client.create');
    }

    public function deleteUser(int $customer_id)
    {
        $this->requestHelper->sendWebhook($customer_id, 'client.delete');
    }

    public function saveNewCustomer(int $customer_id)
    {
        $this->requestHelper->sendWebhook($customer_id, 'client.create');
    }

    public function updateCustomer(int $customer_id)
    {
        $this->requestHelper->sendWebhook($customer_id, 'client.edit');
    }

    public function deleteCustomer(int $customer_id)
    {
        $this->requestHelper->sendWebhook($customer_id, 'client.delete');
    }

}
