<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://sare.pl/
 * @since             1.0.0
 * @package           Sare_Wp
 *
 * @wordpress-plugin
 * Plugin Name:       SARE Woocommerce
 * Plugin URI:        https://sare.pl/
 * Description:       SARE to autorski system, który realizuje spersonalizowaną i zautomatyzowaną komunikację email, SMS, web push oraz umożliwia przeprowadzanie badań ankietowych.
 * Version:           1.0.0
 * Author:            Sare
 * Author URI:        https://sare.pl/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       sare-wp
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SARE_WP_VERSION', '1.0.0' );
define( 'SARE_WP_URL', 'https://shoper.sareapps.pl' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-sare-wp-activator.php
 */
function activate_sare_wp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-sare-wp-activator.php';
	Sare_Wp_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-sare-wp-deactivator.php
 */
function deactivate_sare_wp() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-sare-wp-request-helper.php';
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-sare-wp-deactivator.php';
    $requestHelper = new Sare_Wp_Request_Helper();
    $deactivator = new Sare_Wp_Deactivator();
    $deactivator->deactivate($requestHelper);
}

register_activation_hook( __FILE__, 'activate_sare_wp' );
register_deactivation_hook( __FILE__, 'deactivate_sare_wp' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-sare-wp.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_sare_wp() {

	$plugin = new Sare_Wp();
	$plugin->run();

}

run_sare_wp();
